-----------------------
--- Module Creation ---
-----------------------
local core = LibStub("AceAddon-3.0"):GetAddon("tomQuest2")
local module = core:NewModule("tagQuestLog","AceEvent-3.0", "AceHook-3.0")

-----------------------
--- Library loading ---
-----------------------
local LTQL = LibStub("AceLocale-3.0"):GetLocale("tomQuest2-TagQuestLog")

--------------------------------------------
--- Copy global functions to local scope ---
--------------------------------------------
local min, sub, len = math.min, string.sub, string.len
local GetNumQuestLogEntries, GetQuestLogTitle, HybridScrollFrame_GetOffset = GetNumQuestLogEntries, GetQuestLogTitle, HybridScrollFrame_GetOffset

-----------------
--- variables ---
-----------------
module.modName = LTQL["Quest Log Tag"]

function module:OnInitialize()
	self:SetEnabledState(core:getModuleEnabled("tagQuestLog"))
end

function module:OnEnable()
	self:SecureHook("QuestLog_Update")
end

function module:QuestLog_Update()
	local buttons = QuestLogScrollFrame.buttons
	local numButtons = #buttons
	local offset, numEntries, numQuests = HybridScrollFrame_GetOffset(QuestLogScrollFrame), GetNumQuestLogEntries()
	for i=1, numButtons do
		local index = i + offset
		if index > numEntries then break end
		local title, level, tag, group, header, _, complete, daily, uid = GetQuestLogTitle(index)
		local questLogTitle = buttons[i]
		local questTitleTag, questNormalText, questCheck, questNumGroupMates = questLogTitle.tag, questLogTitle.normalText, questLogTitle.check, questLogTitle.groupMates
		if questCheck then questCheck:Hide() end
		if not header then
			tag, group, daily, level = tag or "", group or 0, daily or 0, level or 0
			if level > 0 or tag ~= "" or group > 0 or daily == 1 then
				title = "  ["..(level > 0 and level or "")..core.db.profile.quests[core.tags[tag]]..(group > 0 and group or "")..(daily == 1 and (tag ~= DAILY and core.db.profile.quests[core.tags[DAILY]] or "") or "").."]"..title
			else
				title = "  "..title
			end
			questLogTitle:SetText(title)
			if (not complete) or (complete == 0) then questTitleTag:SetText("") end
			questNormalText:SetWidth(min(questLogTitle:GetWidth(), 260 - questTitleTag:GetWidth()))
			if uid and core.quests[uid] and core.quests[uid].tracked then
				questCheck:Show()
			end
			local numMates = questNumGroupMates:GetText() or ""
			local numMatesLength = len(numMates)
			if numMatesLength > 0 then
				numMates = sub(numMates, 2, numMatesLength - 1)
				questNumGroupMates:SetText("<"..numMates..">")
				questNumGroupMates:Show()
			else
				questNumGroupMates:Hide()
			end
		end
	end
end